<template>
  <div class="login">
    <div class="login-wrap">
      <img class="login-left" src="../assets/login-left.png" />
      <img class="login-right" src="../assets/login-right.png" />
      <img class="login-logo" src="../assets/menu-logo.png" />
      <img class="login-pic" src="../assets/login-pic.png" />
      <h1>信息化智能化生产管理平台</h1>
      <div class="login-line"></div>
      <h2>Production Management</h2>
      <div class="login-from">
        <el-form ref="form" :model="form" :rules="rules">
          <el-form-item label="手机号" prop="phone">
            <el-input v-model="form.phone" clearable style="width: 280px;"></el-input>
          </el-form-item>
          <el-form-item label="密码" prop="password">
            <el-input ref="password" v-model="form.password" clearable show-password style="width: 280px;"></el-input>
          </el-form-item>
          <el-form-item label="验证码" prop="captcha">
            <el-input ref="captcha" v-model="form.captcha" clearable style="width: 280px;"></el-input>
            <img class="capchaImg" :src="captchaImg" @click.stop="onGetCaptcha()" />
          </el-form-item>
          <el-form-item>
            <el-button type="primary" @click="onLogin">登录</el-button>
            <el-button @click="onCancel">取消</el-button>
          </el-form-item>
        </el-form>
      </div>
      <div class="login-footer">大禹节水集团股份有限公司</div>
    </div>
  </div>
</template>

<style lang="less" scope>
.login {
  width: 100vw;
  height: 100vh;
  background-image: url("../assets/login-bg.png");
  background-repeat: no-repeat;
  background-size: cover;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;

  .login-wrap {
    width: 972px;
    height: 584px;
    border-radius: 20px;
    background-color: #fff;
    position: relative;

    .login-left {
      position: absolute;
      bottom: 70px;
      left: -114px;
    }

    .login-right {
      position: absolute;
      top: 70px;
      right: -115px;
    }

    .login-logo {
      position: absolute;
      top: 45px;
      left: 60px;
    }

    .login-pic {
      position: absolute;
      top: 130px;
      left: 30px;
    }

    h1 {
      position: absolute;
      top: 90px;
      left: 580px;
      font-size: 20px;
      color: #1c50a1;
      font-weight: 700;
    }

    .login-line {
      position: absolute;
      top: 122px;
      left: 580px;
      width: 38px;
      height: 1px;
      background-color: #ccc;
    }

    h2 {
      position: absolute;
      top: 110px;
      left: 620px;
      font-size: 18px;
      color: #ccc;
      font-weight: 400;
    }

    .login-from {
      position: absolute;
      top: 150px;
      left: 580px;
      width: 320px;
      background-color: rgb(255, 255, 255);
      box-sizing: border-box;

      .capchaImg {
        height: 40px;
        position: absolute;
      }
    }

    .login-footer {
      position: absolute;
      bottom: -30px;
      width: 972px;
      text-align: center;
      color: #fff;
      font-size: 14px;

      a {
        color: #fff;
        text-decoration: none;
      }
    }
  }
}
</style>

<script>
export default {
  name: "login",
  data() {
    return {
      form: {
        phone: "admin",
        password: "123456",
        captcha: "1234",
      },
      rules: {
        phone: [
          { required: true, message: "请输入手机号", trigger: "blur" },
          {
            min: 11,
            max: 11,
            message: "长度在 11 位数字",
            trigger: "blur",
          },
        ],
        password: [
          { required: true, message: "请输入密码", trigger: "blur" },
          {
            min: 6,
            max: 6,
            message: "长度为 6 位数字",
            trigger: "blur",
          },
        ],
        captcha: [
          { required: true, message: "请输入验证码", trigger: "blur" },
          {
            min: 4,
            max: 4,
            message: "长度为 4 位数字",
            trigger: "blur",
          },
        ],
      },
      captchaImg: null,
      loading: null,
    };
  },
  mounted() {
    this.onGetCaptcha();
    localStorage.clear();
  },
  watch: {},
  methods: {
    // 路由跳转
    goto: function (path) {
      this.$router.push({
        name: path,
      });
    },
    // 发起登录
    onLogin: function () {
      var that = this;
      var data = that.form;
      that
        .$axiosAdmin({
          method: "post",
          url: "sso/sso/login",
          data: JSON.stringify(data),
        })
        .then((res) => {
          if (res.success == true) {
            localStorage.setItem("id", res.content.id);
            localStorage.setItem("name", res.content.name);
            localStorage.setItem("phone", res.content.phone);
            localStorage.setItem("token", res.content.token);
            that.goto("home");
          } else {
            that.$alert(res.content, "提示", {
              confirmButtonText: "确定",
            });
            localStorage.clear();
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
    // 取消登录
    onCancel: function () {
      this.form.phone = "";
      this.form.password = "";
      this.form.captcha = "";
      localStorage.clear();
    },
    // 获取验证码
    onGetCaptcha: function () {
      this.captchaImg = `sso/sso/captcha?time=${Date.now()}`;
    },
  },
};
</script>
